@@ -35,7 +35,7 @@ under the same terms as Perl itself.
 
 =cut
 
-our $VERSION = '0.008'; # VERSION
+our $VERSION = '0.009'; # VERSION
 
 use Mouse;
 use Carp;
@@ -114,7 +114,7 @@ sub subsets
 {
   my $self = shift;
 
-  return @{$self->{subset}};
+  return @{$self->{subset} // []};
 }
 
 =head2 make_object
